@@ -1,13 +1,13 @@
 use nix::errno::Errno;
 
-use crate::caps::{errors::CapsError, nr, runtime, Capabilities, Capability};
+use crate::caps::{errors::CapsError, nr, Capabilities, Capability};
 
 pub fn clear() -> Result<(), CapsError> {
     #[expect(clippy::disallowed_methods)]
     for flag in Capabilities::all() {
         let cap = flag.try_into().unwrap();
 
-        if has_cap(cap)? {
+        if has_cap(cap).unwrap_or(false) {
             drop(cap)?;
         }
     }
@@ -49,10 +49,10 @@ pub fn read() -> Result<Capabilities, CapsError> {
     let mut res = Capabilities::empty();
 
     #[expect(clippy::disallowed_methods)]
-    for flag in runtime::thread_all_supported() {
+    for flag in Capabilities::all() {
         let cap = flag.try_into().unwrap();
 
-        if has_cap(cap)? {
+        if has_cap(cap).unwrap_or(false) {
             res |= flag;
         }
     }
