@@ -30,14 +30,11 @@ pub(crate) fn sys_mknod(request: UNotifyEventRequest) -> ScmpNotifResp {
         Err(errno) => return request.fail_syscall(errno),
     };
 
-    // SAFETY: Reject undefined/invalid perm.
-    let perm = match to_mode(req.data.args[1]) {
-        Ok(perm) => perm,
-        Err(errno) => return request.fail_syscall(errno),
-    };
+    // SAFETY: Strip undefined/invalid perm bits.
+    let perm = to_mode(req.data.args[1]);
 
     // SAFETY: Reject invalid dev.
-    #[allow(clippy::useless_conversion)]
+    #[expect(clippy::useless_conversion)]
     let dev: libc::dev_t = match req.data.args[2].try_into() {
         Ok(dev) => dev,
         Err(_) => return request.fail_syscall(Errno::EINVAL),
@@ -50,16 +47,11 @@ pub(crate) fn sys_mknod(request: UNotifyEventRequest) -> ScmpNotifResp {
         fsflags: FsFlags::MISS_LAST | FsFlags::NO_FOLLOW_LAST,
         ..Default::default()
     }];
-    syscall_path_handler(
-        request,
-        "mknod",
-        argv,
-        |path_args: PathArgs, request, sandbox| {
-            let umask = sandbox.umask;
-            drop(sandbox); // release the read-lock.
-            syscall_mknod_handler(request, path_args, kind, perm, dev, umask)
-        },
-    )
+    syscall_path_handler(request, "mknod", argv, |path_args, request, sandbox| {
+        let umask = sandbox.umask;
+        drop(sandbox); // release the read-lock.
+        syscall_mknod_handler(request, path_args, kind, perm, dev, umask)
+    })
 }
 
 pub(crate) fn sys_mknodat(request: UNotifyEventRequest) -> ScmpNotifResp {
@@ -71,14 +63,11 @@ pub(crate) fn sys_mknodat(request: UNotifyEventRequest) -> ScmpNotifResp {
         Err(errno) => return request.fail_syscall(errno),
     };
 
-    // SAFETY: Reject undefined/invalid perm.
-    let perm = match to_mode(req.data.args[2]) {
-        Ok(perm) => perm,
-        Err(errno) => return request.fail_syscall(errno),
-    };
+    // SAFETY: Strip undefined/invalid perm bits.
+    let perm = to_mode(req.data.args[2]);
 
     // SAFETY: Reject invalid dev.
-    #[allow(clippy::useless_conversion)]
+    #[expect(clippy::useless_conversion)]
     let dev: libc::dev_t = match req.data.args[3].try_into() {
         Ok(dev) => dev,
         Err(_) => return request.fail_syscall(Errno::EINVAL),
@@ -92,16 +81,11 @@ pub(crate) fn sys_mknodat(request: UNotifyEventRequest) -> ScmpNotifResp {
         fsflags: FsFlags::MISS_LAST | FsFlags::NO_FOLLOW_LAST,
         ..Default::default()
     }];
-    syscall_path_handler(
-        request,
-        "mknodat",
-        argv,
-        |path_args: PathArgs, request, sandbox| {
-            let umask = sandbox.umask;
-            drop(sandbox); // release the read-lock.
-            syscall_mknod_handler(request, path_args, kind, perm, dev, umask)
-        },
-    )
+    syscall_path_handler(request, "mknodat", argv, |path_args, request, sandbox| {
+        let umask = sandbox.umask;
+        drop(sandbox); // release the read-lock.
+        syscall_mknod_handler(request, path_args, kind, perm, dev, umask)
+    })
 }
 
 /// A helper function to handle mknod* syscalls.
@@ -114,7 +98,7 @@ fn syscall_mknod_handler(
     force_umask: Option<Mode>,
 ) -> Result<ScmpNotifResp, Errno> {
     // SAFETY: SysArg has one element.
-    #[allow(clippy::disallowed_methods)]
+    #[expect(clippy::disallowed_methods)]
     let path = args.0.as_ref().unwrap();
 
     // SAFETY:
