@@ -24,7 +24,7 @@ pub(crate) fn handle_sendto(
     fd: OwnedFd,
     args: &[u64; 6],
     request: &UNotifyEventRequest,
-    addr: Option<&SockaddrStorage>,
+    addr: Option<SockaddrStorage>,
     restrict_oob: bool,
 ) -> Result<ScmpNotifResp, Errno> {
     // SAFETY: Reject undefined/invalid flags.
@@ -69,7 +69,7 @@ pub(crate) fn handle_sendto(
 
     let result = if let Some(addr) = addr {
         // Connection-less socket.
-        sendto(fd.as_raw_fd(), &buf, addr, flags)
+        sendto(fd.as_raw_fd(), &buf, &addr, flags)
     } else {
         // Connection mode socket, no address specified.
         send(fd.as_raw_fd(), &buf, flags)
