@@ -54,11 +54,12 @@ use crate::{
         SECCOMP_IOCTL_NOTIF_ADDFD_COOKIE_ARG3, SECCOMP_IOCTL_NOTIF_ADDFD_COOKIE_ARG4,
         SECCOMP_IOCTL_NOTIF_ADDFD_COOKIE_ARG5, SECCOMP_IOCTL_NOTIF_SEND_COOKIE_ARG3,
         SECCOMP_IOCTL_NOTIF_SEND_COOKIE_ARG4, SECCOMP_IOCTL_NOTIF_SEND_COOKIE_ARG5,
-        SOCKET_COOKIE_ARG3, SOCKET_COOKIE_ARG4, SOCKET_COOKIE_ARG5, SYS_ACCEPT4, SYS_BIND,
-        SYS_CONNECT, SYS_SOCKET, TRUNCATE64_COOKIE_ARG4, TRUNCATE64_COOKIE_ARG5,
-        TRUNCATE_COOKIE_ARG2, TRUNCATE_COOKIE_ARG3, TRUNCATE_COOKIE_ARG4, TRUNCATE_COOKIE_ARG5,
-        UNAME_COOKIE_ARG1, UNAME_COOKIE_ARG2, UNAME_COOKIE_ARG3, UNAME_COOKIE_ARG4,
-        UNAME_COOKIE_ARG5, UNLINKAT_COOKIE_ARG3, UNLINKAT_COOKIE_ARG4, UNLINKAT_COOKIE_ARG5,
+        SOCKETPAIR_COOKIE_ARG4, SOCKETPAIR_COOKIE_ARG5, SOCKET_COOKIE_ARG3, SOCKET_COOKIE_ARG4,
+        SOCKET_COOKIE_ARG5, SYS_ACCEPT4, SYS_BIND, SYS_CONNECT, SYS_SOCKET, SYS_SOCKETPAIR,
+        TRUNCATE64_COOKIE_ARG4, TRUNCATE64_COOKIE_ARG5, TRUNCATE_COOKIE_ARG2, TRUNCATE_COOKIE_ARG3,
+        TRUNCATE_COOKIE_ARG4, TRUNCATE_COOKIE_ARG5, UNAME_COOKIE_ARG1, UNAME_COOKIE_ARG2,
+        UNAME_COOKIE_ARG3, UNAME_COOKIE_ARG4, UNAME_COOKIE_ARG5, UNLINKAT_COOKIE_ARG3,
+        UNLINKAT_COOKIE_ARG4, UNLINKAT_COOKIE_ARG5,
     },
     err::{err2no, SydJoinHandle, SydResult},
     fs::{
@@ -941,6 +942,72 @@ impl Worker {
             }
         }
 
+        // socketpair(2) may be used only with syscall argument cookies.
+        //
+        // We only enforce this on architectures where the system call is direct,
+        // and there's no socketcall(2) multiplexer indirection.
+        #[expect(clippy::cast_possible_truncation)]
+        #[expect(clippy::cast_sign_loss)]
+        #[expect(clippy::useless_conversion)]
+        #[expect(deprecated)]
+        if let Some(syscall) =
+            SYS_SOCKETPAIR.map(|n| ScmpSyscall::from_raw_syscall(n as RawSyscall))
+        {
+            // Deny based on socket type.
+            if !flags.allow_unsafe_socket() {
+                for ty in [SOCK_RAW as u64, SOCK_PACKET as u64] {
+                    ctx.add_rule_conditional(
+                        ScmpAction::Errno(EACCES),
+                        syscall,
+                        &[scmp_cmp!($arg1 == ty)],
+                    )?;
+                }
+            }
+
+            // Allow only specified socket domains.
+            let domains = if !flags.allow_unsupp_socket() {
+                let mut domains = vec![AF_UNIX, AF_INET, AF_INET6, AF_NETLINK];
+                if flags.allow_safe_kcapi() {
+                    domains.push(AF_ALG);
+                }
+                Some(domains)
+            } else {
+                None
+            };
+
+            // Secure using syscall argument cookies.
+            let mut rules = vec![];
+            if !flags.allow_unsafe_nocookie() {
+                rules.extend(&[
+                    scmp_cmp!($arg4 == (*SOCKETPAIR_COOKIE_ARG4).into()),
+                    scmp_cmp!($arg5 == (*SOCKETPAIR_COOKIE_ARG5).into()),
+                ]);
+            }
+
+            if let Some(domains) = domains {
+                for domain in domains {
+                    rules.push(scmp_cmp!($arg0 == domain as u64));
+                    ctx.add_rule_conditional(ScmpAction::Allow, syscall, &rules)?;
+                    rules.pop();
+                }
+            } else if rules.is_empty() {
+                ctx.add_rule(ScmpAction::Allow, syscall)?;
+            } else {
+                ctx.add_rule_conditional(ScmpAction::Allow, syscall, &rules)?;
+            }
+        } else {
+            match ScmpSyscall::from_name("socketpair") {
+                Ok(syscall) => {
+                    // Allow socketcall(2).
+                    ctx.add_rule(ScmpAction::Allow, syscall)?;
+                }
+                Err(_) => {
+                    info!("ctx": "confine", "op": "allow_emu_syscall",
+                        "msg": "invalid or unsupported syscall socketpair");
+                }
+            }
+        }
+
         // accept4(2) may be used only with syscall argument cookies.
         //
         // We only enforce this on architectures where the system call is direct,
