@@ -198,7 +198,7 @@ impl Connection {
     fn ctl(&self, epoll: &Epoll, flags: EpollFlags) -> Result<(), Errno> {
         let fd = self.stream.as_raw_fd();
 
-        #[allow(clippy::cast_sign_loss)]
+        #[expect(clippy::cast_sign_loss)]
         let event = libc::epoll_event {
             events: flags.bits() as u32,
             u64: fd as u64,
@@ -309,7 +309,7 @@ impl IpcWorker {
         let epoll = Epoll(epoll_fd);
 
         // Register listener_fd for EPOLLIN.
-        #[allow(clippy::cast_sign_loss)]
+        #[expect(clippy::cast_sign_loss)]
         let event = libc::epoll_event {
             events: EpollFlags::EPOLLIN.bits() as u32,
             u64: sock.as_fd().as_raw_fd() as u64,
@@ -328,7 +328,7 @@ impl IpcWorker {
     }
 
     // Confine IPC thread.
-    #[allow(clippy::cognitive_complexity)]
+    #[expect(clippy::cognitive_complexity)]
     pub(crate) fn prepare_confine(
         epoll_fd: RawFd,
         flags: Flags,
@@ -361,8 +361,8 @@ impl IpcWorker {
         ctx.set_ctl_tsync(false)?;
 
         // Disable Speculative Store Bypass mitigations
-        // with trace/allow_unsafe_spec_exec:1
-        ctx.set_ctl_ssb(flags.allow_unsafe_spec_exec())?;
+        // with trace/allow_unsafe_exec_speculative:1
+        ctx.set_ctl_ssb(flags.allow_unsafe_exec_speculative())?;
 
         // We kill for bad system call and bad arch.
         ctx.set_act_badarch(ScmpAction::KillProcess)?;
@@ -376,7 +376,7 @@ impl IpcWorker {
         // seccomp_add_architectures(&mut ctx)?;
 
         // Allow epoll(7) API to our single epoll fd only.
-        #[allow(clippy::cast_sign_loss)]
+        #[expect(clippy::cast_sign_loss)]
         for sysname in EPOLL_SYSCALLS {
             match ScmpSyscall::from_name(sysname) {
                 Ok(syscall) => {
@@ -432,25 +432,15 @@ impl IpcWorker {
             }
         }
 
-        // Allow safe prctl(2) utility calls.
+        // Allow safe prctl(2) operations.
         let sysname = "prctl";
-        match ScmpSyscall::from_name(sysname) {
-            Ok(syscall) => {
-                // Allow prctl(PR_SET_VMA, PR_SET_VMA_ANON_NAME, ...)
-                // for use during memory sealing of the sandbox policy.
-                ctx.add_rule_conditional(
-                    ScmpAction::Allow,
-                    syscall,
-                    &[
-                        scmp_cmp!($arg0 == libc::PR_SET_VMA as u64),
-                        scmp_cmp!($arg1 == libc::PR_SET_VMA_ANON_NAME as u64),
-                    ],
-                )?;
-            }
-            Err(_) => {
-                info!("ctx": "confine", "op": "allow_ipc_syscall",
-                    "msg": format!("invalid or unsupported syscall {sysname}"));
+        if let Ok(syscall) = ScmpSyscall::from_name(sysname) {
+            for (_, op) in IPC_PRCTL_OPS {
+                ctx.add_rule_conditional(ScmpAction::Allow, syscall, &[scmp_cmp!($arg0 == *op)])?;
             }
+        } else {
+            info!("ctx": "confine", "op": "allow_ipc_syscall",
+                "msg": format!("invalid or unsupported syscall {sysname}"));
         }
 
         // Prevent executable memory.
@@ -476,7 +466,7 @@ impl IpcWorker {
         confine_scmp_write(&mut ctx, None, false)?;
 
         // Allow safe system calls.
-        for sysname in IPC_SYSCALLS {
+        for sysname in IPC_SYSCALLS.iter().chain(VDSO_SYSCALLS) {
             match ScmpSyscall::from_name(sysname) {
                 Ok(syscall) => {
                     ctx.add_rule(ScmpAction::Allow, syscall)?;
@@ -579,7 +569,7 @@ impl IpcWorker {
         // We have to sort the set as the FDs are randomized.
         let poll = self.epoll.as_ref().ok_or(Errno::EADDRNOTAVAIL)?;
         let sock = self.sock.as_ref().ok_or(Errno::EADDRNOTAVAIL)?;
-        #[allow(clippy::cast_sign_loss)]
+        #[expect(clippy::cast_sign_loss)]
         let mut set = vec![
             poll.0.as_raw_fd() as libc::c_uint,
             sock.as_raw_fd() as libc::c_uint,
@@ -593,7 +583,7 @@ impl IpcWorker {
 
     /// Main loop: waits on epoll, accepts new connections,
     /// reads commands, and writes responses.
-    #[allow(clippy::cognitive_complexity)]
+    #[expect(clippy::cognitive_complexity)]
     fn main(&self) -> SydResult<()> {
         let epoll = self.epoll.as_ref().ok_or(Errno::EADDRNOTAVAIL)?;
         let sock = self.sock.as_ref().ok_or(Errno::EADDRNOTAVAIL)?;
@@ -651,7 +641,7 @@ impl IpcWorker {
             };
 
             for ev in events.iter().take(nfds) {
-                #[allow(clippy::cast_possible_truncation)]
+                #[expect(clippy::cast_possible_truncation)]
                 let fd = ev.data() as RawFd;
                 let flags = ev.events();
 
@@ -683,7 +673,7 @@ impl IpcWorker {
         let sock = self.sock.as_ref().ok_or(Errno::EADDRNOTAVAIL)?;
 
         loop {
-            #[allow(unreachable_patterns)]
+            #[expect(unreachable_patterns)]
             match accept4(
                 sock.as_raw_fd(),
                 SockFlag::SOCK_CLOEXEC | SockFlag::SOCK_NONBLOCK,
@@ -695,7 +685,7 @@ impl IpcWorker {
                 Ok(stream) => {
                     // Register the new socket with epoll for reading.
                     let fd = stream.as_fd().as_raw_fd();
-                    #[allow(clippy::cast_sign_loss)]
+                    #[expect(clippy::cast_sign_loss)]
                     let event = libc::epoll_event {
                         events: EpollFlags::EPOLLIN.bits() as u32,
                         u64: fd as u64,
@@ -727,7 +717,7 @@ impl IpcWorker {
     }
 
     /// Handle a readable event on connection `fd`.
-    #[allow(clippy::cognitive_complexity)]
+    #[expect(clippy::cognitive_complexity)]
     fn handle_readable(&self, connections: &mut ConnectionMap, fd: RawFd) -> Result<(), Errno> {
         // Lookup connection by fd.
         // We need a mutable reference; use get_mut.
@@ -737,8 +727,8 @@ impl IpcWorker {
                 let mut iov = [IoSliceMut::new(&mut buf)];
                 let mut cmsg = cmsg_space!(UnixCredentials);
 
-                #[allow(clippy::arithmetic_side_effects)]
-                #[allow(unreachable_patterns)]
+                #[expect(clippy::arithmetic_side_effects)]
+                #[expect(unreachable_patterns)]
                 match recvmsg::<()>(
                     conn.stream.as_raw_fd(),
                     &mut iov,
@@ -872,8 +862,8 @@ impl IpcWorker {
             while conn.write_pos < conn.write_buf.len() {
                 let iov = [IoSlice::new(&conn.write_buf[conn.write_pos..])];
 
-                #[allow(clippy::arithmetic_side_effects)]
-                #[allow(unreachable_patterns)]
+                #[expect(clippy::arithmetic_side_effects)]
+                #[expect(unreachable_patterns)]
                 match sendmsg::<()>(
                     conn.stream.as_raw_fd(),
                     &iov,
@@ -919,7 +909,7 @@ impl IpcWorker {
     }
 
     // Process at `pos` boundary from connection `conn` on `fd`.
-    #[allow(clippy::cognitive_complexity)]
+    #[expect(clippy::cognitive_complexity)]
     fn process_command(&self, conn: &mut Connection, pos: usize) -> Result<(), Errno> {
         let epoll = self.epoll.as_ref().ok_or(Errno::EADDRNOTAVAIL)?;
 
